//
// jquery.showPassword.js - Show and hide the contents of a password input on demand.
//
// Developed by Cory LaViska for A Beautiful Site, LLC
//
// Licensed under the MIT license: http://opensource.org/licenses/MIT
//
if(jQuery) (function($) {
  'use strict';

  // Defaults
  $.showPassword = {
    defaults: {
      change: function() {}
    }
  };

  // Create the plugin
  $.extend($.fn, {
    showPassword: function(method, options) {
      if(typeof method === 'object') options = method;

      // Public API
      switch(method) {
      case 'destroy':
        return $(this).each(destroy);

      default:
        return $(this).each(function() {
          create.call(this, $.extend({}, $.showPassword.defaults, options));
        });
      }
    }
  });

  // Create the control
  function create(options) {
    var trigger = this;

    $(trigger).on('click.showPassword', function(event) {
      // Prevent clicks on links from hijacking the page
      if($(event.input).parents().addBack().is('a')) {
        event.preventDefault();
      }

      // Toggle the input
      toggle.call({
        trigger: this,
        options: options
      }, this, event);
    });
  }

  // Destroy the control
  function destroy() {
    $(this).off('click.showPassword');
  }

  // Toggle a password/text field
  function toggle() {
    var trigger = this.trigger;
    var options = this.options || {};
    var input = $(options.input);
    var type = $(input).prop('type') === 'password' ? 'text' : 'password';

    // Change the input type
    $(input).prop('type', type);

    // Fire change callback
    if(options.change) {
      options.change.call(trigger, type);
    }
  }
})(jQuery);
